API Docs
========

.. automodule:: flask_webpackext.ext
    :members:

Proxies
-------

.. automodule:: flask_webpackext.proxies
    :members:

Manifest
--------

.. automodule:: flask_webpackext.manifest
    :members:

Project
-------

.. automodule:: flask_webpackext.project
   :members:

Bundle
------

.. automodule:: flask_webpackext.bundle
   :members:

Command Line Interface
----------------------

.. click:: flask_webpackext.cli:webpack
   :prog: flask webpack
   :show-nested:
